@@ -31,28 +31,3 @@ has 'linkreports'       => (is => 'rw', isa => 'Str');
 
 
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-WWW::WuFoo::User - The Users API is used to gather details about the users you have defined through User Management.
-
-=head1 VERSION
-
-version 0.002
-
-=head1 AUTHOR
-
-Peter Lytle <pete@bluecampaigns.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Peter Lytle.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
